@@ -1,50 +1,6 @@
 #' @importFrom RColorBrewer brewer.pal
 #' @importFrom grDevices rainbow
 
-objcheck.func <- function(para.list=para.list,ite=ite,OB.vec=OB.vec
-                        ,paraname.p=paraname.p,ite.ob=ite.ob,printcheck=T
-                        ,obcheck.start=1,e.cri=e.cri){
-
-  if(is.logical(printcheck))printcheck<-ifelse(printcheck,2,0)
-
-  ob.list<-OBJfunc(para.list)
-  OB.vec[ite.ob]<-ob.list$obval
-  saved.list<-ob.list$saved.list
-
-  obval <- OB.vec[ite.ob]
-
-  if(ite.ob>obcheck.start){
-
-    if( OB.vec[ite.ob]-OB.vec[ite.ob-1] > 0){#if(printcheck)
-      # browser()
-      #if(printcheck>1) cat("  obvalue is increased by",OB.vec[ite.ob]-OB.vec[ite.ob-1],"at",ite,"th ite,",paraname.p,"update.\n")
-      down.para.save<-paraname.p
-    }else{
-      down.para.save<-FALSE
-    }
-
-    if(abs(OB.vec[ite.ob]-OB.vec[ite.ob-1])<e.cri){
-      #if(printcheck>2) cat(paste("  ",ite,"th ite converge at",paraname.p,"update.\n"))
-      OB.vec[(ite.ob+1):length(OB.vec)]<-OB.vec[ite.ob]
-      convergence<-TRUE
-      #break
-    }else{
-      convergence<-FALSE
-    }
-
-
-  }else{
-    #if(printcheck>2) cat(("  skip checking\n"))
-    down.para.save<-F
-    convergence<-F
-  }
-
-  ite.ob2<-ite.ob+1
-
-  list(OB.vec=OB.vec,ite.ob=ite.ob2,saved.list=saved.list
-       ,down.para.save=down.para.save,convergence=convergence)
-}
-
 
 
 list2mat.func<-function(data=data,inputform=c("list")#,ndata=ndata
@@ -69,11 +25,11 @@ list2mat.func<-function(data=data,inputform=c("list")#,ndata=ndata
   if("matrix" %in% outputform){
     if(whichsame=="row"){
       data.mat<-matrix(0,rowvec[1],col.all)
-      #if(any(rowvec[1]!=rowvec))print("To combine matrix, all row needs to be the same.")
+      if(any(rowvec[1]!=rowvec))warning("To combine matrix, all row needs to be the same.")
 
     }else if(whichsame=="col"){
       data.mat<-matrix(0,row.all,colvec[1])
-      #if(any(colvec[1]!=colvec)) print("To combine matrix, all column needs to be the same.")
+      if(any(colvec[1]!=colvec)) warning("To combine matrix, all column needs to be the same.")
     }}
 
 
@@ -135,7 +91,7 @@ create.color.func<-function(ncolor=ncolor,transpare=FALSE,printcheck=FALSE
       #browser()
       #cols2<-rainbow(ncolor-12)
       cols<-rep(c(cols1,cols2), ceiling(ncolor/20))[1:ncolor]
-      #if(ncolor>20)print("ncolor is >20. so same color is repeated.")
+      if(ncolor>20)message("ncolor is >20. so same color is repeated.")
     }
   }else{
     #cols<-heat.colors(ncolor)
